{% extends 'generic/object.html' %}
{% block content %}
  <div class="row mb-3">
    <div class="col col-md-6">
      <div class="card">
        <h5 class="card-header">Access List</h5>
        <div class="card-body">
          <table class="table table-hover attr-table">
            <tr>
              <th scope="row">Destination</th>
              <td>{{ object.destination_prefix }}</td>
            </tr>
            <tr>
              <th scope="row">Site</th>
              <td>
                <a href="{{ object.site.get_absolute_url }}">{{ object.site }}</a>
              </td> 
            </tr>  
            <tr>
              <th scope="row">Device</th>
              <td>
                <a href="{{ object.device.get_absolute_url }}">{{ object.device }}</a>
              </td>
            </tr>
            <tr>
              <th scope="row">VRF</th>
              <td>
                <a href="{{ object.vrf.get_absolute_url }}">{{ object.vrf }}</a>
              </td>
            </tr>
            <tr>
              <th scope="row">Next Hop</th>
              <td>{{ object.next_hop }}</td>
            </tr>
            <tr>
              <th scope="row">Distance</th>
              <td>{{ object.distance }}</td>
            </tr>
          </table>
        </div>
      </div>
      {% include 'inc/panels/custom_fields.html' %}
    </div>
    <div class="col col-md-6">
      {% include 'inc/panels/tags.html' %}
      {% include 'inc/panels/comments.html' %}
    </div>
  </div>
{% endblock content %}